##  Search in Your Preferred Language
When viewing a translated page, enter your search term in the search bar in that language. Select the page you need from the search results.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob06d38074fb34f60b2abb54fd0a78e6f_LowRes.png)
Example: Searching in German
If your selected language is English, you can use advanced search features. Search for exact words or phrases, or filter out unwanted keywords to narrow down your results.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio8398162b0bfb460d89158331245e11ff_LowRes.png)
Advanced Search Options for English
